import { LoremMedium } from "../components/Loremipsum";
import { BlockQuoteB } from "../components/Quotes";
import { Section } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";

export function Judging() {
  useTabNavigation();
    return (
      <>
        <Section title="Overview" id="Overview">
          <BlockQuoteB text="Judging for iGEM is one of the highlights on my professional calendar…" cite="Dr. Nancy Burgess, Director of Judging at iGEM HQ"/>
          <p>The iGEM competition celebrates innovation in synthetic biology, offering teams the chance to compete for a range of awards based on their achievements in 
            various categories. Judging is based on how well teams integrate scientific rigor with societal impact, safety, and creativity. We aim to compete for 
            several prestigious awards, including <b>Best Integrated Human Practices</b>, <b>Biosafety and Security</b> Award, and <b>Best New Basic Part</b>. Additionally, we seek recognition for our <b>therapeutic project</b> and will strive for excellence in best wiki, best promotional video, and the iGEMers prize. </p>
        </Section>
        <Section title="Best Therapeutic Project" id="Best Therapeutic Project">
          <p>Our project is a dual therapeutic approach targeting cystic fibrosis (CF), specifically the most common mutation, F508del. We aim to develop a curative solution by correcting the genetic defect using Prime Editing Technology while enhancing the folding of the CFTR protein. Additionally, we developed a Lipid Nanoparticle for the cell-specific targeting of lung epithelial cells. This project directly addresses the unmet therapeutic needs of CF patients, providing a long-term and potentially curative solution. </p>
          <h4>Has the team clearly defined the therapeutic problem they are addressing? </h4>
          <p>We are addressing Cystic Fibrosis (CF), a severe genetic disorder caused by mutations in the CFTR gene, particularly the F508del mutation. This mutation leads to thick mucus accumulation in vital organs, causing chronic infections and damage, particularly in the lungs. Our focus on the F508del mutation, which affects around 90 % of CF patients in Europe and beyond, ensures our project targets a well-defined and widespread therapeutic need. </p>
          <h4>How well is the therapeutic mechanism of action understood and demonstrated? </h4>
          <p>Our project employs a dual approach: </p>
          <ol>
            <li>orrecting the F508del mutation using our Prime Editing Technology	PrimeGuide, a well understood gene editing tool designed to repair defective genes</li>
            <li>delivering of our mRNA therapeutic via specialized Lipid Nanoparticles AirBuddy, ensuring direct application in lung epithelial cells</li>
          </ol>
          <h4>Has the team validated the effectiveness of their therapeutic approach? </h4>
          <p>We tested the therapeutic efficacy <i>in vitro</i> using patient-derived primary epithelial cells in Air Liquid Culture (ALI) and Apical-Out Organoids carrying the F508del mutation. These cells were treated with PreCyse to assess the genetic correction, while downstream applications will validate the improved folding and function of the CFTR protein. Our experimental design allows us to gather proof-of-concept data, demonstrating the viability of both gene correction and efficient delivery. </p>
          <h4>Does the project consider off-target effects or unintended consequences?</h4>
          <p>By incorporating FANZOR, a new eukaryotic RNA-binding DNA-endonucleases, we enhance the precision of Prime Editing. Site-directed mutagenesis enable nickasification of our CasX and FANZOR candidates. This enables the usage as Prime Editor, while enhancing efficiency and decreasing PE complex size. We have designed our system to minimize unintended consequences, ensuring that our therapeutic intervention is safe for clinical application. </p>
          <h4>What potential does the project have for real-world therapeutic applications? </h4>
          <p>Our dual approach has significant potential for real-world therapeutic applications. PreCyse provides a curative genetic solution, improve immediate physiological functions. The project addresses a crucial need in CF therapy by targeting both the root genetic cause and the resulting protein dysfunction, offering a more comprehensive solution than current treatments. </p>
          <h4>How well did the team integrate safety into their therapeutic design? </h4>
          <p>Safety is a priority in our project. The use of FANZOR enhances the specificity of our gene-editing approach, reducing the likelihood of off-target gene modifications. Additionally, we are committed to rigorous <i>in vitro</i> testing before advancing to <i>in vivo</i> models, ensuring that our therapeutic interventions do not pose risks to patients. For this, we developed an CF-specific fluorescence-based Reporter System mimicking the CF-specific genomic alteration. </p>
          <h4>To what extent has the team considered patient impact? </h4>
          <p>We have closely aligned our project with patient needs by targeting the F508del mutation, which affects a significant portion of CF patients worldwide. Our therapeutic solution aims to improve quality of life by addressing the root cause of CF and reducing the burden of lifelong treatments. We are also in contact with CF patients and have gathered insights from healthcare providers to ensure our therapy is patient-centric. PreCyse offers a long-time solution, while being cost-efficient and easy-to-use. </p>
          <p>Our innovative therapeutic project leverages the power of gene editing and protein modulation to offer a potentially curative solution for Cystic Fibrosis, particularly for the prevalent F508del mutation. With a well-validated scientific foundation, comprehensive safety measures, and a strong focus on patient needs, we believe our project exemplifies the qualities deserving of the <b>Best Therapeutic Project Award</b>. Our dual approach provides a template for future genetic disease treatments, paving the way for more effective and personalized medical solutions. </p>
        </Section>
        <Section title="Best Integrated Human Practice" id="Best Integrated Human Practice">
          <LoremMedium/>
        </Section>
        <Section title="Best New Part" id="New Basic Part">
          <LoremMedium/>
        </Section>
        <Section title="Safety and Security" id="Safety and Security">
          <LoremMedium/>
        </Section>
        

      </>
    );
  }
  